@@ -3,6 +3,8 @@ import socket
 import tarfile
 import logging
 
+from distutils.util import strtobool
+
 from pathlib import Path
 
 from django.conf import settings
@@ -15,12 +17,16 @@ logger = logging.getLogger(__name__)
 
 
 def get_backup_name(filepath, hostname=None, projectname=None, all=False):
-    if not isinstance(hostname, str):
+    if not isinstance(hostname, str) or len(hostname) == 0:
         hostname = socket.gethostname()
-    if not isinstance(projectname, str):
+        logger.debug(f"set hostname to {hostname}")
+    if not isinstance(projectname, str) or len(projectname) == 0:
+        logger.debug(f"set projectname to {BackupUtilsConfig.PROJECT_NAME}")
         projectname = BackupUtilsConfig.PROJECT_NAME
 
+    logger.debug(f"get_backup_name({filepath}, hostname={hostname}, projectname={projectname}, all={all})")
     splits = str(Path(filepath).name).split("_")
+    logger.debug(f"splitted path: {splits}")
 
     if len(splits) == 4:
         splits_hostname = splits[0]
@@ -28,10 +34,12 @@ def get_backup_name(filepath, hostname=None, projectname=None, all=False):
 
         if all:
             if str(filepath).endswith(".tar.gz") or str(filepath).endswith(".tar"):
+                logger.debug(f"get_backup_name -> return {filepath}")
                 return filepath
 
         if splits_hostname == hostname and splits_project == projectname:
             if str(filepath).endswith(".tar.gz") or str(filepath).endswith(".tar"):
+                logger.debug(f"get_backup_name -> return {filepath}")
                 return filepath
 
 
@@ -56,9 +64,11 @@ def get_system_migrations():
 
 
 def get_migration_file_list():
+    logger.debug('get_migration_file_list()')
     f = MigrationRecorder.Migration.objects.all()
     migration_files = []
     not_found = []
+    consistent = True
     missing_migrations = ""
     for each in f.order_by('applied'):
         if Path(f"{settings.BASE_DIR}/{each.app}").is_dir():
@@ -70,24 +80,34 @@ def get_migration_file_list():
 
     if not_found:
         for each in not_found:
+            logger.debug(f"missing migration: {each}")
             missing_migrations += str(each) + "\n"
         if not BackupUtilsConfig.BACKUP_IGNORE_CONSISTENCY:
             raise MigrationNotFound(missing_migrations)
         else:
-            logger.warning(f'some migration-files are missing, backup could be inconsistent\n{missing_migrations}')
+            logger.warning(
+                f'some migration-files are missing, backup could be inconsistent missing:\n{missing_migrations}')
+            consistent = False
 
-    return migration_files
+    return migration_files, consistent
 
 
 def extract_dumpinfo(tarpath):
+    logger.debug(f"extract_dumpinfo({tarpath})")
     dump_info = tarfile.open(str(tarpath), "r")
     dump_info = dump_info.extractfile(f'{BackupUtilsConfig.DUMPINFO}').readlines()
     created_at = dump_info[0].decode("UTF-8").strip().split(";")[1]
-    system_version = dump_info[1].decode("UTF-8").strip().split(";")[1]
-    dump_version = dump_info[2].decode("UTF-8").strip().split(";")[1]
-    system_migrations_migrated = dump_info[3].decode("UTF-8").strip().split(";")[1]
-    system_migration_files = dump_info[4].decode("UTF-8").strip().split(";")[1]
+    logger.debug(f'created_at: {created_at}')
+    dump_version = dump_info[1].decode("UTF-8").strip().split(";")[1]
+    logger.debug(f'dump_version: {dump_version}')
+    system_migrations_migrated = dump_info[2].decode("UTF-8").strip().split(";")[1]
+    logger.debug(f'system_migrations_migrated: {system_migrations_migrated}')
+    dump_migration_files = dump_info[3].decode("UTF-8").strip().split(";")[1]
+    logger.debug(f'dump_migration_files: {dump_migration_files}')
+    consistent_migrations = strtobool(dump_info[4].decode("UTF-8").strip().split(";")[1])
+    logger.debug(f'consistent_migrations: {consistent_migrations}')
     params = dump_info[5].decode("UTF-8").strip().split(";")[1]
-    return {'created_at': created_at, "system_version": system_version, "dump_version": dump_version,
-            "system_migrations_migrated": system_migrations_migrated, "system_migration_files": system_migration_files,
-            "params": params}
+    logger.debug(f'params: {params}')
+    return {'created_at': created_at, "dump_version": dump_version,
+            "system_migrations_migrated": system_migrations_migrated, "dump_migration_files": dump_migration_files,
+            "params": params, 'consistent_migrations': consistent_migrations}
